==> aipark-api-28.32-sources.jar: de/aipark/api/requestsResponse/getCostsForParkingAreas/CostsForParkingAreasEntry.java <==
package de.aipark.api.requestsResponse.getCostsForParkingAreas;

import io.swagger.annotations.ApiModelProperty;

import java.util.Currency;

/**
 * Created by torgen on 21.01.18.
 */
public class CostsForParkingAreasEntry {
    @ApiModelProperty(value = "parking area id for the request", dataType = "java.lang.Long", required = true, example = "2612812")
    private Long parkingAreaId;

    @ApiModelProperty(value = "costs for parking area for the requested time frame (in cent or equivalent smallest currency unit)", dataType = "java.lang.Integer", required = true, example = "10")
    private Integer costs;

    @ApiModelProperty(value = "currency (the costs are in cent or equivalent smallest currency unit)", dataType = "java.lang.String", required = true, example = "EUR")
    private Currency currency;

    public CostsForParkingAreasEntry() {
        this.currency = Currency.getInstance("EUR");
    }

    public CostsForParkingAreasEntry(Long parkingAreaId, Integer costs) {
        this.parkingAreaId = parkingAreaId;
        this.costs = costs;
        this.currency = Currency.getInstance("EUR");
    }

    public CostsForParkingAreasEntry(Long parkingAreaId, Integer costs, Currency currency) {
        this.parkingAreaId = parkingAreaId;
        this.costs = costs;
        this.currency = currency;
    }

    public Long getParkingAreaId() {
        return parkingAreaId;
    }

    public void setParkingAreaId(Long parkingAreaId) {
        this.parkingAreaId = parkingAreaId;
    }

    public Integer getCosts() {
        return costs;
    }

    public void setCosts(Integer costs) {
        this.costs = costs;
    }

    public Currency getCurrency() {
        return currency;
    }

    public void setCurrency(Currency currency) {
        this.currency = currency;
    }

    @Override
    public String toString() {
        return "CostsForParkingAreasEntry{" +
                "parkingAreaId=" + parkingAreaId +
                ", costs=" + costs +
                ", currency=" + currency +
                '}';
    }
}

==> aipark-api-30.05-sources.jar: de/aipark/api/requestsResponse/getCostsForParkingAreas/CostsForParkingAreasEntry.java <==
package de.aipark.api.requestsResponse.getCostsForParkingAreas;

import io.swagger.annotations.ApiModelProperty;

import java.util.Currency;

/**
 * Created by torgen on 21.01.18.
 */
public class CostsForParkingAreasEntry {
    @ApiModelProperty(value = "parking area id for the request", dataType = "java.lang.Long", required = true, example = "2612812")
    private Long parkingAreaId;

    @ApiModelProperty(value = "costs for parking area for the requested time frame (in cent or equivalent smallest currency unit)", dataType = "java.lang.Integer", required = true, example = "10")
    private Integer costs;

    @ApiModelProperty(value = "3-digit currency code defined by ISO 4217 (the costs are in cent or equivalent smallest currency unit)", dataType = "java.lang.String", required = true, example = "EUR")
    private Currency currency;

    public CostsForParkingAreasEntry() {
        this.currency = Currency.getInstance("EUR");
    }

    public CostsForParkingAreasEntry(Long parkingAreaId, Integer costs) {
        this.parkingAreaId = parkingAreaId;
        this.costs = costs;
        this.currency = Currency.getInstance("EUR");
    }

    public CostsForParkingAreasEntry(Long parkingAreaId, Integer costs, Currency currency) {
        this.parkingAreaId = parkingAreaId;
        this.costs = costs;
        this.currency = currency;
    }

    public Long getParkingAreaId() {
        return parkingAreaId;
    }

    public void setParkingAreaId(Long parkingAreaId) {
        this.parkingAreaId = parkingAreaId;
    }

    public Integer getCosts() {
        return costs;
    }

    public void setCosts(Integer costs) {
        this.costs = costs;
    }

    public Currency getCurrency() {
        return currency;
    }

    public void setCurrency(Currency currency) {
        this.currency = currency;
    }

    @Override
    public String toString() {
        return "CostsForParkingAreasEntry{" +
                "parkingAreaId=" + parkingAreaId +
                ", costs=" + costs +
                ", currency=" + currency +
                '}';
    }
}
